@@ -3,9 +3,11 @@
 # license that can be found in the LICENSE file.
 
 import os
-import yaml
+import pwd
 import subprocess
 
+import yaml
+
 
 def load_config(**kwargs):
     watcher = kwargs.get("watcher")
@@ -19,10 +21,16 @@ def load_config(**kwargs):
     return {}
 
 
+def set_uid(watcher):
+    uid = pwd.getpwnam(watcher.uid).pw_uid
+    os.setuid(uid)
+
+
 def run_commands(name, **kwargs):
     from tsuru.stream import Stream
     config = load_config(**kwargs)
     watcher = kwargs.get("watcher")
+    set_uid(watcher)
     cmds = config.get('hooks', {}).get(name, [])
     if cmds:
         Stream(watcher_name=watcher.name)(
